@@ -34,6 +34,10 @@ if [ !  -e "${prefix}/dev/zero" ]; then
     mknod -m 666 "${prefix}/dev/zero" c 1 5
 fi
 
+if [ !  -e "${prefix}/dev/null" ]; then
+    mknod -m 666 "${prefix}/dev/null" c 1 3
+fi
+
 if [ !  -e "${prefix}/dev/random" ]; then
     mknod -m 666 "${prefix}/dev/random" c 1 8
     chown root:root "${prefix}/dev/random"
